# Script that uses the bife package to estimate logit models with many fixed effects.

  library(bife)
  library(data.table)
  library(haven)
  library(lfe)
  library(boot)
  
  sink("C:/Userdata/Shared/Output/School, political participation/LogitOutput191127")  
# Read in the data used for estimation  
  bifeData <- read_dta("D:/Data/ProjData/School, political participation/mod/Finaldataset.dta")
  setDT(bifeData)
  
  bifeData[, politicians_pq := share_nompe*50]
  
# Recode some variables   
  bifeData[, dturnout_e := turnout_e/100]
  bifeData[, dturnout_r := turnout_r/100]
  bifeData[, di_evernominated := i_evernominated/100]
  bifeData[, di_everelected := i_everelected/100]
  bifeData[, AvgAr := as.factor(avgar)]
  bifeData[, schoolprogram := as.factor(schoolprogram)]
  
  # Create strings with variable names
  depvar <- c("dturnout_e", "dturnout_r", "di_evernominated", "di_everelected")
  CovInd         <- c("i_sex", "i_immig")
  CovParent      <- c("f_socialbidragfamilj", "f_sysselsatt", "f_yearseducation", "f_zink", "m_socialbidragfamilj",  "m_sysselsatt", "m_yearseducation", "m_zink")
  CovParentClass <- c("share_f_socialbidragfamilj", "share_f_sysselsatt",  "share_f_yearseducation", "share_f_zink",  
                      "share_m_socialbidragfamilj", "share_m_sysselsatt", "share_m_yearseducation", "share_m_zink")
  indvar <- "politicians_pq"
  groupvar <- "schoolprogram"
  year <- "as.factor(avgar)"  
  
  # Create model formulas based on the strings with variable names
  FullCov <- paste(paste(indvar, collapse = " + "),
                   paste(CovInd, collapse=" + "), 
                   paste(CovParent, collapse=" + "),
                   paste(CovParentClass, collapse=" + "),
                   paste(year, "|", groupvar, sep=""), sep = " + ")
  
  fm1 <- as.formula(paste(depvar[1], FullCov, sep=" ~ "))
  fm2 <- as.formula(paste(depvar[2], FullCov, sep=" ~ "))
  fm3 <- as.formula(paste(depvar[3], FullCov, sep=" ~ "))
  fm4 <- as.formula(paste(depvar[4], FullCov, sep=" ~ "))
  
  
cat("###########################################Logit results EP election ###############################################\n")  
  # Run model with EP turnout as dependent variable  
  tmp <- proc.time()
  modlogit1 <- bife(fm1, data = bifeData[avgar >= 1996 & parent_nompe != 1 & avgar < 2009, ])
  summary(modlogit1)  
cat("#####################################################################################################################\n")
    
cat("#####################################################################################################################\n")
cat("#  Marginal effects for EP turnout                                                                                   \n")
cat("#####################################################################################################################\n")  
  mfx1 <- get_APEs(modlogit1)
  summary(mfx1)
  
  proc.time()-tmp
 
cat("#####################################################################################################################\n")
 
cat("########################################Logit results National election ###############################################\n")   
  # Run model with national turnout as dependent variable 
  tmp <- proc.time()
  modlogit2 <- bife(fm2, data = bifeData[avgar >= 1996 & parent_nompe != 1 & avgar <= 2010, ])
  summary(modlogit2)  
  
  cat("#####################################################################################################################\n")
  cat("#  Marginal effects for National turnout                                                                             \n")
  cat("#####################################################################################################################\n")  
  
  mfx2 <- get_APEs(modlogit2)
  summary(mfx2)
  proc.time()-tmp
  
  cat("#####################################################################################################################\n")
  
  cat("###########################################Logit results Nomination ###############################################\n")  
  
  # Run model with nomination as dependent variable
  tmp <- proc.time()
  modlogit3 <- bife(fm3, data = bifeData[avgar >= 1996 & parent_nompe != 1 & avgar <= 2010, ])
  summary(modlogit3)  
  
  cat("#####################################################################################################################\n")
  cat("#  Marginal effects for Nomination                                                                            \n")
  cat("#####################################################################################################################\n")  
  
  mfx3 <- get_APEs(modlogit3)
  summary(mfx3)
  proc.time()-tmp
  
  cat("#####################################################################################################################\n")
  
  cat("###########################################Logit results Election ###############################################\n")  
  # Run model with election as dependent variable
  tmp <- proc.time()
  modlogit4 <- bife(fm4, data = bifeData[avgar >= 1996 & parent_nompe != 1 & avgar <= 2010, ])
  summary(modlogit4)  
  
  
  cat("#####################################################################################################################\n")
  cat("#  Marginal effects for Election                                                                             \n")
  cat("#####################################################################################################################\n")  
  
  mfx4 <- get_APEs(modlogit4)
  summary(mfx4)
  proc.time()-tmp
  
  cat("#####################################################################################################################\n")
  
  
sink()
