********************************************************************************
************************Datamangement dofile************************************ 
********************************************************************************

clear all
clear matrix
set more off, perm
capture log close
log using "C:/Userdata/Shared/Logs/School, political participation/datamanagement.text", replace text 
do "C:/Userdata/Shared/Dofiles/DoData/School, political participation/programs.do"		/*See separate program dofile*/
cd "D:/Data/ProjData/School, political participation/mod/"


********************************************************************************
* This dofiles concists of the following parts:
* (1): Creating the data set that is used for descriptive statistics, dataanalysis and robustness
* The dofile uses temp files created in initialize and file preparation. 
********************************************************************************



** The starting point is the application register for Swedish high school (Sökanderegistret) **
use "Sokande.dta", clear
gen avgar = prodar + 3															/*Upper secondary school is 3 years long*/

* Write number of observations to txt file
file open numbers using "C:\Userdata\Shared\Output\School, political participation\numbers.txt", write replace
su LopNr if avgar < 2011
file write numbers "Unika löpnummer i sökanderegistret som avgår före 2011: `r(N)'" _n

** Merge with school-code key to compensate for changes in school codes**
merge m:m skolkod_HT_LopNr skolenhetskod_HT_LopNr using "D:/SCB_ConPol/Stata/Utbild/SkolKodConPol_Gym", nogen keep(1 3) keepusing(SkolkodConpol) /*We may use m:m merge in this case, since the only duplicates are the missing values and they are dropped below*/
replace SkolkodConpol = . if skolkod_HT_LopNr == . & skolenhetskod_HT_LopNr == .
gen program_highschool = stvkod_HT
gen id_highschool = string(SkolkodConpol)
drop if missing(program_highschool) | missing(SkolkodConpol)

*Removing numbers after school codes that are year specific*
replace program_highschool = regexr(program_highschool,"[0-9]+","")

* Remove last letters from program code until there have been at least 100 students on the program
forvalues i = 1/6 {
	bysort program_highschool: egen count = count(LopNr)
	replace program_highschool = substr(program_highschool,1,strlen(program_highschool)-1) if count < 100
	drop count
}

* Count schools in a municipality												/*No variation in Kommun_HT conditional on id_highschool. This is correct! */
bysort id_highschool avgar: gen count = 1 if _n == 1
bysort Kommun_HT avgar: egen schools = total(count)
drop count Kommun_HT

*Dropping special educational programs*											
drop if substr(program_highschool,1,2) == "IV"									/*"IV" ("Individuellt val") is a high school program for those students not eligle for regular high school programs. These students reapply to high school later.*/

*Drop if program has 1 letter code*
drop if strlen(program_highschool) == 1											/*Drop programs with just one letter (national programs have 2 letters)*/

* Keeping 2 letter national programs
replace program_highschool = substr(program_highschool,1,2)						/*Using the first 2 letters as information of program in high school. Additional information concerns local subtracks. We want to focus on the national educational programs. */
drop if program_highschool == "Ö" 												/* Drop "övriga" program because we do not know whether these people read the same, or different, programs */

* Write number of observations to txt file. Used to assess accuracy
su LopNr if avgar < 2011
file write numbers "Kvarvarande observationer efter att IV-programmet och missing values rensats bort: `r(N)'" _n		/*Translation: Number of observations after IV-program and missing values have been removed*/

* Drop if program has fewer than 5 students during a given year
bys id_highschool program_highschool avgar: egen temp = count(LopNr)
drop if temp < 5
drop temp

* Write number of observations to txt file. Used to assess accuracy
su LopNr if avgar < 2011
file write numbers "Kvarvarande observationer efter att även klasser med färre än 5 studenter rensats bort: `r(N)'" _n	/*Translation: Remaining number of observation after classes with less than 5 students have been removed. */

*Saving relevant variables*
keep LopNr avgar program_highschool id_highschool schools





** Here we start building the data set for the relevant populaton: Adding information from the birth-register**
merge 1:1 LopNr using "Fodelseuppg.dta", keep(1 3) nogen keepusing(FodArMan Kon F_delselandGrupp)		
gen birthyear = real(substr(string(FodArMan),1,4))
gen birthmonth = real(substr(string(FodArMan),5,2))

** Adding serial numbers for the student's parents **
merge 1:1 LopNr using "flergen.dta", nogen keep(3)

** Adding election data for the parents and include the two years before the graduation year **
rename LopNr LopNrBK															/*Fathers*/
rename lopnrfar LopNr

merge m:1 LopNr using "everpolitician.dta", nogen keep(1 3)

gen evernominatedbefore = .
gen everelectedbefore = .
replace evernominatedbefore = 1 if minyearnom < (avgar-3) & minyearnom != . & evernominated == 1
replace everelectedbefore = 1 if minyearelec < (avgar-3) & minyearelec != . & everelected == 1

gen evernominatedafter = .
gen everelectedafter = .
replace evernominatedafter = 1 if minyearnom > (avgar) & minyearnom != . & evernominated == 1
replace everelectedafter = 1 if minyearelec > (avgar) & minyearelec != . & everelected == 1

drop minyearnom minyearelec

gen year = avgar

merge m:1 LopNr year using "politicians.dta", nogen keep(1 3 4) assert(1 2 3 4) update 
replace year = avgar - 1

merge m:1 LopNr year using "politicians.dta", nogen keep(1 3 4) assert(1 2 3 4) update			
replace year = avgar - 2

merge m:1 LopNr year using "politicians.dta", nogen keep(1 3 4) assert(1 2 3 4) update
drop year

foreach v in elected nominated inoffice nompe nompe_M nompe_KD nompe_L nompe_C nompe_MP nompe_S nompe_V nompe_SD toppe everelected evernominated evermodeparti evertop evernominatedbefore everelectedbefore evernominatedafter everelectedafter {
	rename `v' father_`v'
	replace father_`v' = 0 if father_`v' == .
}


rename LopNr lopnrfar															/*Mothers*/
rename lopnrmor LopNr

merge m:1 LopNr using "everpolitician.dta", nogen keep(1 3) 
gen evernominatedbefore = .
gen everelectedbefore = .
replace evernominatedbefore = 1 if minyearnom < (avgar-3) & minyearnom != . & evernominated == 1
replace everelectedbefore = 1 if minyearelec < (avgar-3) & minyearelec != . & everelected == 1

gen evernominatedafter = .
gen everelectedafter = .
replace evernominatedafter = 1 if minyearnom > (avgar) & minyearnom != . & evernominated == 1
replace everelectedafter = 1 if minyearelec > (avgar) & minyearelec != . & everelected == 1


drop minyearnom minyearelec

gen year = avgar

merge m:1 LopNr year using "politicians.dta", nogen keep(1 3 4) assert(1 2 3 4) update
replace year = avgar - 1

merge m:1 LopNr year using "politicians.dta", nogen keep(1 3 4) assert(1 2 3 4) update
replace year = avgar - 2

merge m:1 LopNr year using "politicians.dta", nogen keep(1 3 4) assert(1 2 3 4) update
drop year

foreach v in elected nominated inoffice nompe nompe_M nompe_KD nompe_L nompe_C nompe_MP nompe_S nompe_V nompe_SD toppe everelected evernominated evermodeparti evertop evernominatedbefore everelectedbefore evernominatedafter everelectedafter {
	rename `v' mother_`v'
	replace mother_`v' = 0 if mother_`v' == .
}
foreach v in father mother {
	gen `v'_evernotinoffice = 0		
	gen `v'_evernotnompe = 0
	replace `v'_evernotinoffice = 1 if `v'_everelected==1 & `v'_inoffice==0 
	replace `v'_evernotnompe = 1 if `v'_evernominated==1 & `v'_nompe==0 
}

*Creating parental variables (both fathers and mothers)	
foreach v in elected nominated inoffice nompe toppe everelected evernominated evertop nompe_C nompe_L nompe_KD nompe_M nompe_MP nompe_S nompe_V nompe_SD evernominatedafter everelectedafter {
	gen parent_`v' = 0
	replace parent_`v' = 1 if father_`v' == 1 | mother_`v' == 1
}

gen parent_evernotinoffice = 0 
gen parent_evernotnompe = 0
replace parent_evernotinoffice = 1 if father_evernotinoffice == 1 | mother_evernotinoffice == 1
replace parent_evernotnompe = 1 if father_evernotnompe == 1 | mother_evernotnompe == 1

rename LopNr lopnrmor
rename LopNrBK LopNr


** Adding additional information on parents**
capture drop FodArMan
rename LopNr LopNrBK
rename lopnrfar LopNr

merge m:1 LopNr using "Fodelseuppg.dta", keep(1 3) nogen keepusing(FodArMan)		
rename LopNr lopnrfar
rename lopnrmor LopNr
gen father_age = avgar - real(substr(string(FodArMan),1,4))
drop FodArMan

merge m:1 LopNr using "Fodelseuppg.dta", keep(1 3) nogen keepusing(FodArMan)		
rename LopNr lopnrmor
rename LopNrBK LopNr  
gen mother_age = avgar - real(substr(string(FodArMan),1,4))
drop FodArMan




** Defining immigration status indiviudal**
capture drop FodArMan
rename F_delselandGrupp i_F_delselandGrupp
gen i_immig = 0
replace i_immig = 1 if i_F_delselandGrupp != "Sverige"





** Adding dependent variables for the individuals **

* Elite participation
merge 1:1 LopNr using "everpolitician.dta", nogen keep(1 3)						/* Elite participation: Whether the individual has been nominated or elected after upper secondary school */
replace evernominated = 0 if evernominated == .
replace everelected = 0 if everelected == .
replace evermodeparti = 0 if evermodeparti == .

* Party variables
foreach p in M KD L C S MP V SD {
	replace evernominated_`p' = 0 if evernominated_`p' == .
	replace everelected_`p' = 0 if everelected_`p' == .
}


* Mass participation *
merge 1:1 LopNr using Valdelt_2009, nogen keep(1 3) keepusing(e)				/* Mass participation: Voter turnout in the 2009 EP election and the general election in 2010 */	
merge 1:1 LopNr using Valdelt_2010, nogen keep(1 3) keepusing(r k l)

* Defining variables for voter turnout
foreach i in e r k l {															/* Voter turnout EP election 2009. Parlimentary election, county election and municipal election in 2010 originates from the same raw data file (Common election day for all three elections). We only focus on voter turnout in the national election 2010 as an outcome. */
	gen turnout_`i' = 0
	replace turnout_`i' = 1 if `i' == 2 | `i' == 4 | `i' == 5 | `i' == 6
	replace turnout_`i' = . if `i' == 3
}
drop e r k l


* Rescale dependent variables to 0 or 100 to faciliate interpretation. 
foreach v in evernominated everelected turnout_e turnout_r turnout_k turnout_l {
	replace `v' = `v' * 100
}



* Adding residential location for the graduation year *							/*To be used because of kommungrad. Used below*/
merge 1:1 LopNr avgar using "SAMS_panel", nogen keep(1 3) keepusing(SAMS)
rename SAMS sams_grad 
gen kommungrad = substr(sams_grad,1,4)




** Generating main treatment variables: Number of politicians in a specific class (upper secondary school, for a specific program, for a specific graduation year) **
gen class = ""
replace class = id_highschool + "_" + program_highschool + "_" + string(avgar)  /* As indicated in the paper: These groups are not neccesarily "classes", but a combination of school+program+year */

gen schoolprogram = ""
replace schoolprogram = id_highschool + "_" + program_highschool


*Mechanism treatment variable: Parents politician, but their child did not vote in the 2009 EP election*
gen father_vt09no = 0
replace father_vt09no = 1 if turnout_e == 0 & father_nompe == 1 


gen mother_vt09no = 0
replace mother_vt09no = 1 if turnout_e == 0 & mother_nompe == 1 

gen parent_vt09no = 0
replace parent_vt09no = 1 if turnout_e == 0 & (mother_nompe == 1 | father_nompe == 1)




* Calculate shares of politicians in a "class" *
bysort class: egen count = count(LopNr)											/* Count the number of politicians in a class, subtract the student's own parents and divide by the size of the group */
foreach v in elected nominated inoffice nompe vt09no toppe everelected evernominated evertop evernotinoffice evernotnompe nompe_C nompe_L nompe_KD nompe_M nompe_MP nompe_S nompe_V nompe_SD {
	foreach p in parent father mother {
		bysort class: egen sum_`p'_`v' = sum(`p'_`v')
			
		* Generate shares for lags and leads*									/*To be used in the analysis in the online appendix.*/
		gen l_share_`p'_`v' = (sum_`p'_`v' / count) / 2							/*This variable will be calculated further below. Note: You do not have a parent in the lag and the lead share*/
		
		* Generate treatment shares*
		replace sum_`p'_`v' = sum_`p'_`v' - `p'_`v'								/*Share not including the individual's parents for the year the student applied to upper secondary school*/
		gen share_`p'_`v' = sum_`p'_`v' / (count-1)
		replace share_`p'_`v' = share_`p'_`v' / 2 								/* Assuming two parents per student */
		drop sum_`p'_`v'
	}
	

* Shorten variable names and drop father/mother variables that are not further used. 
rename share_parent_`v' share_`v'
rename l_share_parent_`v' l_share_`v'
drop share_father_`v' share_mother_`v'
drop l_share_father_`v' l_share_mother_`v'
}


* Calculate share of politicians from a given political party in a class. Used in the online appendix. 
foreach p in mother father parent {
gen `p'_M = 0
gen `p'_KD = 0
gen `p'_L = 0
gen `p'_C = 0
gen `p'_S = 0
gen `p'_MP = 0
gen `p'_V = 0
gen `p'_SD = 0
gen `p'_centerright = 0
gen `p'_centerleft = 0

replace `p'_M = 1 if `p'_nompe == 1
replace `p'_KD = 1 if `p'_nompe == 68
replace `p'_L = 1 if `p'_nompe == 3
replace `p'_C = 1 if `p'_nompe == 4 

replace `p'_S = 1 if `p'_nompe == 2
replace `p'_MP = 1 if `p'_nompe == 55
replace `p'_V = 1 if `p'_nompe == 5

replace `p'_centerright = 1 if (`p'_nompe == 1 | `p'_nompe == 68 | `p'_nompe == 3 |`p'_nompe == 4)  
replace `p'_centerleft = 1 if (`p'_nompe == 2 | `p'_nompe == 55 | `p'_nompe == 5) 
}

foreach p in mother father parent {
	foreach k in M KD L C S MP V SD centerright centerleft {
		bysort class: egen sum_`p'_`k' = sum(`p'_`k')
			
		* Generate treatment shares*
		replace sum_`p'_`k' = sum_`p'_`k' - `p'_`k'								/*Share not including the individual's parents for the year the student applied to upper secondary school*/
		gen share_`p'_`k' = sum_`p'_`k' / (count-1)
		replace share_`p'_`k' = share_`p'_`k' / 2 								/* Assuming two parents per student */
		drop sum_`p'_`k'
	}
}

*Rescale and rename dependent politcal party variable 
foreach k in M KD L C S MP V SD {
	replace evernominated_`k' = evernominated_`k'*100
	rename evernominated_`k' i_`k'
	
}



** Lags and leads: To be used in the analysis in the online appendix **
preserve
unab lagvars : l_*
collapse `lagvars', by(schoolprogram avgar)
rename l_* *
ds schoolprogram avgar, not 
foreach k of var `r(varlist)' {										
	bys schoolprogram (avgar): gen `k'_lag1 = `k'[_n-1]  
	bys schoolprogram (avgar): gen `k'_lead1 = `k'[_n+1]
	drop `k'
}
save "lagsleads.dta", replace
restore

* Adding lags and leads to the main data set*
merge m:1 schoolprogram avgar using "lagsleads.dta", nogen keep(1 3)			




** Adding information for municipal fixed effects for 2009**		
merge 1:1 LopNr using "SAMS_2009", nogen keep(1 3) keepusing(SAMS)
rename SAMS sams2009 
gen kommun2009 = substr(sams2009,1,4)





** Add data for placebo outcomes **

*Conscription data*
merge 1:1 LopNr using "conscription", nogen keep(1 3)

* Grades from ninth grade*
merge 1:1 LopNr using "AK9.dta", nogen keep(1 3)

* Grades from graduation from upper secondary school *
merge 1:1 LopNr using "AvgGymn.dta", nogen keep(1 3) keepusing(GBP)







** Adding individual covariates **
compress																		/*Making the data set as small as possible before some big mergers*/
merge 1:1 LopNr using "LISA_2009", keep(1 3) nogen
foreach v in SocBidrFam yearseducation Lisayear {
	rename `v' i_`v'
}

* Recoding and renaming gender covariate for the indiviudal*
gen i_sex = 0 if Kon == 1
replace i_sex = 1 if Kon == 2


rename everelected i_everelected
rename evernominated i_evernominated
rename evermodeparti i_evermodeparti
rename LoneInk i_Loneink 




** Adding parental covariates for the graduation year**

/*Fathers*/	
rename LopNr LopNrBK
rename lopnrfar LopNr
merge m:1 LopNr avgar using "LISAcovparent_panel", keep(1 3) nogen
merge m:1 LopNr avgar using "SAMS_panel", keep(1 3) nogen 

rename LopNr lopnrfar
rename sysselsatt f_sysselsatt
rename yearseducation f_yearseducation
rename socialbidragfamilj f_socialbidragfamilj
rename zink f_zink
rename SAMS sams_f_grad

/*Mothers*/
rename lopnrmor LopNr 															
merge m:1 LopNr avgar using "LISAcovparent_panel", keep(1 3) nogen
merge m:1 LopNr avgar using "SAMS_panel", keep(1 3) nogen 

rename LopNr lopnrmor
rename sysselsatt m_sysselsatt
rename yearseducation m_yearseducation
rename socialbidragfamilj m_socialbidragfamilj
rename LopNrBK LopNr
rename zink m_zink
rename SAMS sams_m_grad




** Adding parental voter turnout data **
rename LopNr LopNrBK
rename lopnrfar LopNr
merge m:1 LopNr using Valdelt_2009, nogen keep(1 3) keepusing(e)				/* Fathers 2009 */	
merge m:1 LopNr using Valdelt_2010, nogen keep(1 3) keepusing(r)				/* Fathers 2010 */	

gen turnout_f_e = 0
replace turnout_f_e = 1 if e == 2 | e == 4 | e == 5 | e == 6
replace turnout_f_e = . if e == 3
drop e 

gen turnout_f_r = 0
replace turnout_f_r = 1 if r == 2 | r == 4 | r == 5 | r == 6
replace turnout_f_r = . if r == 3
drop r
rename LopNr lopnrfar

rename lopnrmor LopNr
merge m:1 LopNr using Valdelt_2009, nogen keep(1 3) keepusing(e)				/* Mothers 2009 */
merge m:1 LopNr using Valdelt_2010, nogen keep(1 3) keepusing(r)				/* Mothers 2010 */	

gen turnout_m_e = 0
replace turnout_m_e = 1 if e == 2 | e == 4 | e == 5 | e == 6
replace turnout_m_e = . if e == 3
drop e

gen turnout_m_r = 0
replace turnout_m_r = 1 if r == 2 | r == 4 | r == 5 | r == 6
replace turnout_m_r = . if r == 3
drop r

rename LopNr lopnrmor
rename LopNrBK LopNr

gen turnout_anyparents_e = .
replace turnout_anyparents_e = 1 if turnout_f_e == 1 | turnout_m_e == 1
replace turnout_anyparents_e = 0 if turnout_f_e == 0 & turnout_m_e == 0


**Add data on discussing politics from the ULF-survey **

merge 1:1 LopNr using "polintULF.dta", nogen keep(1 3)




** Recoding and defining relevant variables for individuals and parents. Dropping variables that we do not use**
destring i_* f_* m_* Conscriptionyear, replace  
drop Kon i_F_delselandGrupp Befl Gvkap Gckap Sun2000niva_old SyssStatJ id_highschool








** Calculate peer-effect covariates shares **									/*In addition to indiviudal and parental covariates, we also add covariates on the class level*/
drop count
bys class: egen count = count(LopNr)	
foreach v in socialbidragfamilj sysselsatt yearseducation zink {
	foreach p in f m {
		bys class: egen sum_`p'_`v' = sum(`p'_`v')
		
		* Generate treatment shares
		replace sum_`p'_`v' = sum_`p'_`v' - `p'_`v'								/*Share not including the individuals parents*/
		gen share_`p'_`v' = sum_`p'_`v' / (count-1)
		replace share_`p'_`v' = share_`p'_`v' / 2 
		drop sum_`p'_`v'
	}

}




** Who is mobilized?: Generate vote propensity **								/*This is used to calculate "Nascent political ambition"*/
local vars i_sex GPA_9 f_socialbidragfamilj f_sysselsatt f_yearseducation f_zink m_socialbidragfamilj m_sysselsatt m_yearseducation m_zink father_age mother_age
local varsbefore father_evernominatedbefore mother_evernominatedbefore father_everelectedbefore mother_everelectedbefore
local varsafter turnout_f_e turnout_m_e turnout_f_r turnout_m_r

* Estimate probability of participation 
foreach dv in turnout_e turnout_r i_evernominated i_everelected {
	areg `dv' `vars' `varsbefore' `varsafter', absorb(kommungrad) 
	predict hat2_`dv', xbd
	gen rhat2_`dv' = round(hat2_`dv',10)
}




* Truncate all propensities at 0 and 100
unab hats : hat* rhat*
di "`hats'"
foreach v in `hats' {
	replace `v' = 0 if `v' < 0
	replace `v' = 100 if `v' > 100 & `v' != .
	gen sq`v' = `v' ^2
	gen below`v' = `v'
	replace below`v' = 0 if `v' > 50 & `v' != .
	gen above`v' = `v'
	replace above`v' = 0 if `v' < 50
}


** Write number of observations to txt file: Number of observations to check accuracy for different samples (taking into account missing values etc.) **
su LopNr if avgar < 2011
file write numbers "Kvarvarande observationer efter att hela datamanagement körts: `r(N)'" _n							/* Translation: Number of observations after running datamangement dofile.*/
su LopNr if avgar < 2011 & parent_nompe != 1 & missing(i_sex) == 0
file write numbers "Och om vi exkluderar de med politikerföräldrar samt de där vi saknar kön: `r(N)'" _n				/* Translation: Number of observations excluding indiviudals with politicians parents and where we lack information on gender*/
su LopNr if avgar < 2009 & parent_nompe != 1 & missing(i_sex) == 0
file write numbers "Exkluderas åren 2009 och 2010 får vi alla i turnout_e: `r(N)'" _n									/* Translation: Number of observations if excluding the graduation years 2009 and 2010.*/
su LopNr if avgar < 2011 & parent_nompe != 1 & missing(i_sex) == 0 & missing(turnout_r) == 0
file write numbers "Exkluderas alla utan rösträtt i riksdagsvalet (missing values) får vi alla i turnout_r: `r(N)'" _n	/* Translation: Number of observations if exluding all without the right to vote in the national election in 2010 (missing values)*/


* Remove all temp files from temp folder
local keep finaldataset.dta
local files : dir "" files *
local erase : list files - keep
foreach f in `erase' {
	erase "`f'"
}


** Final save of data set **
compress
save "Finaldataset.dta", replace
file close numbers
clear all
log close

