********************************************************************************
*****************************Descriptive statistics*****************************
********************************************************************************


clear all
clear matrix
set more off, perm
capture log close
log using "C:/Userdata/Shared/Logs/School, political participation/descriptive.text", replace text									
cd "D:/Data/ProjData/School, political participation/mod/"
global outputfolder "C:/Userdata/Shared/Output/School, political participation"

********************************************************************************
* This dofiles concists of the following parts:
* (1): Creating a long term trend figures with regards to our outcome variables 
* (2): Descriptive statistics for the size of the treatment group 
* (3): Descriptive statistics for outcomes and convariates (3 column table)
********************************************************************************


** Long term trend figures **
use "Finaldataset.dta", clear
destring LopNr, replace

gen treatment_politiker = 0
replace treatment_politiker = 1 if share_nompe > 0 

* Main treatment
gen politicians_pq`i' = share_nompe`i' * 50	// pq = per quinquaginta

foreach k in turnout_e turnout_r i_evernominated i_everelected {
	preserve
	keep if avgar <= 2010
		if "`k'" == "turnout_e" {
		drop if avgar > 2009
		}
	bysort avgar treatment_politiker: egen dep_`k' = mean(`k')
	gen `k'_notpol = dep_`k' if treatment_politiker == 0
	gen `k'_pol = dep_`k' if treatment_politiker == 1
	bysort avgar: egen `k'_all = mean(`k')  
	collapse `k'_pol `k'_notpol `k'_all, by(avgar)
	label var `k'_notpol "No parent pol." 
	label var `k'_pol "At least 1 parent pol." 
	label var `k'_all "All" 
	twoway (line `k'_notpol avgar, lcolor(black) lpattern(dash)) (line `k'_pol avgar, lcolor(black) lpattern(solid)), ///
		ytitle("Percent of cohort") xtitle("Graduation year") ///
		ylab(,nogrid) xla(2000 2005 2010) ///
		yscale(titlegap(1.5)) xscale(titlegap(1.5)) ///
		legend(region(lstyle(none))) ///
		scheme(s1mono) graphregion(color(white)) 
	graph export "C:/Userdata/Shared/Output/School, political participation/img/LongTerm_`k'.pdf", replace as(pdf)
	graph export "C:/Userdata/Shared/Output/School, political participation/img/LongTerm_`k'.eps", replace as(eps)
	restore
}







** Collapse by class for class size descriptives **


preserve
keep if avgar <= 2010 & missing(class) == 0
collapse (count) TreatmentgroupNS=LopNr (mean) share_evernominated share_nominated share_everelected share_inoffice, by(class avgar)




** Histogram size of treatment group **
hist TreatmentgroupNS, ///
	percent ytitle("Percent") xtitle("Number of students") ///
	ylab(,nogrid) ///
	yscale(titlegap(1.5)) xscale(titlegap(1.5)) ///
	scheme(s1mono) fcolor(gs10) lwidth(thin) graphregion(color(white))
graph export "C:/Userdata/Shared/Output/School, political participation/img/descriptivehistogram.pdf", replace as(pdf)
graph export "C:/Userdata/Shared/Output/School, political participation/img/descriptivehistogram.eps", replace as(eps)

sum TreatmentgroupNS															/*Number used in the text.*/ 

** Size of the treatment group over time**
collapse (mean) TreatmentgroupNS, by(avgar)
label var TreatmentgroupNS ""

twoway (line TreatmentgroupNS avgar), ///
	ytitle("Number of students") xtitle("Graduation year") ///
	ylab(,nogrid) xla(2000 2005 2010) ///
	yscale(titlegap(1.5)) xscale(titlegap(1.5)) ///
	scheme(s1mono) graphregion(color(white))
graph export "C:/Userdata/Shared/Output/School, political participation/img/NstudentsTime.pdf", replace as(pdf)
graph export "C:/Userdata/Shared/Output/School, political participation/img/NstudentsTime.eps", replace as(eps)

restore

** Politicians per 25 students **

preserve
capture drop count
keep if avgar >= 1996 & parent_nompe != 1 & avgar <= 2010						//Equivalent to includeouther-global in dataanalysis dofile. 
bys class: gen count = _n
hist politicians_pq, ///
	percent ytitle("Percent") xtitle("Politicians per 25 students") ///
	ylab(,nogrid) ///
	yscale(titlegap(1.5)) xscale(titlegap(1.5)) ///
	scheme(s1mono) fcolor(gs10) lwidth(thin) graphregion(color(white))
graph export "C:/Userdata/Shared/Output/School, political participation/img/hist_politicians_individuals.pdf", replace as(pdf)
graph export "C:/Userdata/Shared/Output/School, political participation/img/hist_politicians_individuals.eps", replace as(eps)
hist politicians_pq if count == 1, percent ///
	ytitle("Percent") xtitle("Politicians per 25 students") ///
	ylab(,nogrid) ///
	yscale(titlegap(1.5)) xscale(titlegap(1.5)) ///
	scheme(s1mono) fcolor(gs10) lwidth(thin) graphregion(color(white))
graph export "C:/Userdata/Shared/Output/School, political participation/img/hist_politicians_classes.pdf", replace as(pdf)
graph export "C:/Userdata/Shared/Output/School, political participation/img/hist_politicians_classes.eps", replace as(eps)

sum politicians_pq, detail														/*Numbers used in the text*/

restore







** Descriptive statistics: 3 column table for outcomes and covariates **
 
* Program which writes row with means for descriptive table AND updates min and max number of observations
assert missing(politicians_pq) == 0
capture program drop row
program row

	su `1' if avgar <= 2010
	local mean : di %03.2f r(mean)
	global maxobs1 = max(`r(N)',${maxobs1})
	global minobs1 = min(`r(N)',${minobs1})
	file write descriptives "`2' & `mean'"
	
	su `1' if politicians_pq == 0 & avgar <= 2010
	local mean : di %03.2f r(mean)
	global maxobs2 = max(`r(N)',${maxobs2})
	global minobs2 = min(`r(N)',${minobs2})
	file write descriptives " & `mean'"
	
	su `1' if politicians_pq > 0 & avgar <= 2010
	local mean : di %03.2f r(mean)
	global maxobs3 = max(`r(N)',${maxobs3})
	global minobs3 = min(`r(N)',${minobs3})
	file write descriptives " & `mean' \\" _n

end

* Clear macros
global maxobs1 .
global maxobs2 .
global maxobs3 .
global minobs1 .
global minobs2 .
global minobs3 .

capture file close descriptives
file open descriptives using "${outputfolder}/tex/descriptives.tex", write replace
file write descriptives "\begin{tabular}{l*{3}{D{.}{.}{3.2}}}" _n
file write descriptives "\toprule" _n
file write descriptives "Variable & \multicolumn{1}{c}{Full sample} & \multicolumn{1}{c}{No politician} & \multicolumn{1}{c}{At least one} \\" _n
file write descriptives "\midrule" _n
row turnout_e "Turnout 2009"
row turnout_r "Turnout 2010"
row i_evernominated "Ever nominated"
row i_everelected "Ever elected"
row politicians_pq "Parent politicians per 25 students"
row i_sex "Woman"
row i_immig "Foreign born"
row f_yearseducation "Years of education, father"
row m_yearseducation "Years of education, mother"
row f_zink "Standardized income, father"
row m_zink "Standardized income, mother"
row f_socialbidragfamilj "Social assistance recipient, father"
row m_socialbidragfamilj "Social assistance recipient, mother"
row f_sysselsatt "Father employed"
row m_sysselsatt "Mother employed"
file write descriptives "&&&\\" _n
file write descriptives "Observations (min)& \multicolumn{1}{c}{$minobs1} & \multicolumn{1}{c}{$minobs2} & \multicolumn{1}{c}{$minobs3} \\" _n
file write descriptives "Observations (max)& \multicolumn{1}{c}{$maxobs1} & \multicolumn{1}{c}{$maxobs2} & \multicolumn{1}{c}{$maxobs3} \\" _n
file write descriptives "\bottomrule" _n
file write descriptives "\end{tabular}" _n
file close descriptives

* Clear macros
global maxobs1
global maxobs2
global maxobs3
global minobs1
global minobs2
global minobs3




*****
log close
clear all
