********************************************************************************
*******************************Filepreparation********************************** 
********************************************************************************

clear all
clear matrix
set more off, perm
capture log close
log using "C:/Userdata/Shared/Logs/School, political participation/filepreparation.text", replace text 
cd "D:/Data/ProjData/School, political participation/mod/"


********************************************************************************
* This dofiles concists of the following parts:
* (1): Creating panels for elected and nominated politicians. 
* (2): Creating panels for the covariates
********************************************************************************



** Create panel of politicians **
gen LopNr = .
gen year = .
gen nominated = .
gen elected = .
gen top = .
local elections 1982 1985 1988 1991 1994 1998 2002 2006 2010
foreach y in `elections' {
	foreach i in KO LT RI {
		
		merge 1:1 LopNr year using "Nom_`y'_`i'.dta", nogen update
		capture rename politiker_ politiker_`i' 								// The variable has the wrong name in the files in mod which are based on the raw data file Nominerade_KO_82_85_88_94. Changing this. 
		replace nominated = 1 if politiker_`i' == 1
		drop politiker_`i'
		
		merge 1:1 LopNr year using "Valda_`y'_`i'.dta", nogen update
		replace elected = 1 if politiker_`i' == 1
		replace top = 1 if politiker_`i' == 1 & ("`i'" == "RI" | nrinom == 1)
		drop politiker_`i' nrinom
	}
}
su nominated elected top

** Party-specific panel **
local parties C L KD M MP S V SD  
foreach p in `parties' {
	gen nominated_`p' = .
	gen elected_`p' = .
}

foreach y in `elections' {
	foreach i in KO LT RI {
	
		di "År: `y', Val: `i'"
		merge 1:1 LopNr year using "Nom_`y'_`i'.dta", nogen update keepusing(politiker_ partyabb)
		capture rename politiker_ politiker_`i'
		foreach p in `parties' {
			replace nominated_`p' = 1 if politiker_`i' == 1 & upper(partyabb) == "`p'"
		}
		drop politiker_`i' partyabb
		
		merge 1:1 LopNr year using "Valda_`y'_`i'.dta", nogen update keepusing(politiker_ partyabb)
		foreach p in `parties' {
			replace elected_`p' = 1 if politiker_`i' == 1 & upper(partyabb) == "`p'"
		}
		drop politiker_`i' partyabb 
		
	}
}



** Create variable for when in office ** 										/*Note that the year "after" the election is a good match for "avgångsår" since that is only spring) */
tsset LopNr year
tsfill, full
tsappend, add(4)
gen inoffice = .
replace inoffice = 1 if L.elected == 1
replace inoffice = 1 if L2.elected == 1
replace inoffice = 1 if L3.elected == 1
replace inoffice = 1 if L4.elected == 1 & year > 1995							/*4 year mandate periods was implemented in Sweden after 1994*/

* Create a similar variable for those who were nominated in the previous election *
gen nompe = .
replace nompe = 1 if L.nominated == 1
replace nompe = 1 if L2.nominated == 1
replace nompe = 1 if L3.nominated == 1
replace nompe = 1 if L4.nominated == 1 & year > 1995

* And a similar variable for political parties *
local parties M KD L C S MP V SD 
foreach p in `parties' {
	gen nompe_`p' = .
	replace nompe_`p' = 1 if L.nominated_`p' == 1
	replace nompe_`p' = 1 if L2.nominated_`p' == 1
	replace nompe_`p' = 1 if L3.nominated_`p' == 1
	replace nompe_`p' = 1 if L4.nominated_`p' == 1 & year > 1995
}


* And the top candidates (note that "nrinom" is missing for 1991 and 1994)
gen toppe = .
replace toppe = 1 if L.top == 1
replace toppe = 1 if L2.top == 1
replace toppe = 1 if L3.top == 1
replace toppe = 1 if L4.top == 1 & year > 1995

* Clean and save
drop if elected == . & nominated == . & inoffice == . & nompe == .
preserve
drop parti 															
save "politicians.dta", replace
restore

* And remove the time dimension
gen minyearnom = year if nominated == 1
gen minyearelec = year if elected == 1
bysort LopNr (year): egen evermodeparti = mode(parti), maxmode							
collapse (max) elected elected_* nominated nominated_* top (min) minyearnom minyearelec evermodeparti, by(LopNr)
rename elected everelected
rename elected_* everelected_*
rename nominated evernominated
rename nominated_* evernominated_*
rename top evertop		
save "everpolitician.dta", replace


** Create panel of LISA covariates for parents **

*Panel covariates parent*
use "LISAcovparent_1990", clear
forvalues k=1991/2010 {
	append using "LISAcovparent_`k'"
}
compress
save "LISAcovparent_panel", replace

*SAMS panel*
use "SAMS_1982", replace
forvalues k=1983/2010  {
	append using "SAMS_`k'" 
	
}
rename year avgar
save "SAMS_panel", replace

**********
log close
clear all
