********************************************************************************
*****************Initialize dofile**********************************************
********************************************************************************

clear all
clear matrix
set more off, perm
cd "D:/Data/ProjData/School, political participation/mod/"
capture log close
log using "C:/Userdata/Shared/Logs/School, political participation/initialize.text", replace text									
do "C:/Userdata/Shared/Dofiles/DoData/School, political participation/programs.do"		/*See separate program dofile*/


********************************************************************************
* This dofiles concists of the following parts:
* (1): Cleaning the data registers that we use in the project 
* (2): Saving relevant variables to reduce the size of the data sets 
********************************************************************************

* Applied to high school (Sökanderegistret)
use "D:/SCB_ConPol/Stata/Utbild/sokint94_15.dta"
egen maxyear = max(prodar), by(LopNr)
drop if prodar != maxyear
keep if antstat == 1 
duplicates tag LopNr, gen(dup)
destring utbort, replace force
drop if Kommun_HT != utbort & dup > 0
drop dup
duplicates tag LopNr, gen(dup)
drop if real(rang) != valutfall & dup > 0
drop dup
dupprogram
save "Sokande.dta", replace


* Graduated from highschool 
use "D:/SCB_ConPol/Stata/Utbild/AvgGymn.dta", clear
dupprogram
save "AvgGymn.dta", replace

* Voter turnout 2009 EU-election*
use "D:/SCB_ConPol/Stata/VD/Valdelt_09.dta", clear
dupprogram
keep LopNr kommun_id distrikt_id e Rostratt
save "Valdelt_2009.dta", replace

* Voter turnout 2010*
use "D:/SCB_ConPol/Stata/VD/Valdelt_2010.dta", clear
dupprogram
keep LopNr kommun_id distrikt_id r k l Rostratt
save "Valdelt_2010.dta", replace

* Data on birth year/month and immigration status*
use "D:/SCB_ConPol/Stata/flergen/Fodelseuppg.dta", clear
dupprogram
keep LopNr FodArMan Kon F_delselandGrupp UtlSvBakG 
save "Fodelseuppg.dta", replace

* Multigenerational register*
use "D:/SCB_ConPol/Stata/flergen/BioForaldrar.dta", clear
keep LopNr lopnrmor lopnrfar
dupprogram
save "flergen.dta", replace

* Multigenerational register, adopted*
use "D:/SCB_ConPol/Stata/flergen/AdForaldrar.dta", clear
keep LopNr LopNrAdMor LopNrAdFar
dupprogram
gen adopterad = 1
save "flergen_adopted.dta", replace

* Conscription data *
use "D:/SCB_ConPol/Stata/monstring/da856.dta", clear
split Monstringsdatum, parse(/)
rename Monstringsdatum3 Conscriptionyear
keep LopNr Befl Psyf Gkap Gvkap Gckap Conscriptionyear 
save "conscription.dta", replace

* Elected politicians*

foreach j in KO LT RI {											
	foreach k in 1982 1985 1988 {
	use "D:/SCB_ConPol/Stata/NomVald/valda_`j'_82_85_88.dta", clear
		keep if valar == `k'
		capture gen nrinom = .
		capture destring nrinom, replace force
		capture rename Partikod partikod
		gen politiker_`j' = 1
		
		gen partyabb = ""
		if "`j'" == "KO" {
			replace partyabb = "c" if pnamn_kort == "Centerpartiet"
			replace partyabb = "l" if pnamn_kort == "Folkpartiet"
			replace partyabb = "kd" if pnamn_kort == "Kristdemokraterna"
			replace partyabb = "m" if pnamn_kort == "Miljöpartiet"
			replace partyabb = "mp" if pnamn_kort == "Moderaterna"
			replace partyabb = "s" if pnamn_kort == "Socialdemokraterna"
			replace partyabb = "v" if pnamn_kort == "Vänsterpartiet"
			replace partyabb = "sd" if pnamn_kort == "Sverigedemokraterna"		 
		}
		
		if "`j'" != "KO" {
			replace partyabb = "c" if partikod == 4
			replace partyabb = "l" if partikod == 3
			replace partyabb = "kd" if partikod == 68
			replace partyabb = "m" if partikod == 1
			replace partyabb = "mp" if partikod == 55
			replace partyabb = "s" if partikod == 2
			replace partyabb = "v" if partikod == 5
			replace partyabb = "sd" if partikod == 110
		}
		rename partyabb partyabbtemp
		bysort LopNr: egen partyabb = mode(partyabbtemp)
		collapse politiker_`j' (min) nrinom (firstnm) partyabb, by(LopNr) 		/*We are interested in having a politicians as a class, not which constituency a politician was elected in. Therefore we may collapse*/
		gen year = `k'
		label var politiker_`j' ""
		save "Valda_`k'_`j'.dta", replace
		}
	}
foreach j in KO LT RI {
	foreach k in 1991 1994 1998 2002 2006 2010 {
		use "D:/SCB_ConPol/Stata/NomVald/Valda_`k'_`j'.dta", clear
		capture gen nrinom = .
		capture destring nrinom, replace force
		capture rename Partikod partikod
		gen politiker_`j' = 1
		gen partyabb = ""
		replace partyabb = "c" if partikod == 4
		replace partyabb = "l" if partikod == 3
		replace partyabb = "kd" if partikod == 68
		replace partyabb = "m" if partikod == 1
		replace partyabb = "mp" if partikod == 55
		replace partyabb = "s" if partikod == 2
		replace partyabb = "v" if partikod == 5
		replace partyabb = "sd" if partikod == 110
		rename partyabb partyabbtemp
		bysort LopNr: egen partyabb = mode(partyabbtemp), maxmode
		collapse politiker_`j' (min) nrinom partyabb, by(LopNr) 
		gen year = `k'
		label var politiker_`j' ""
		save "Valda_`k'_`j'.dta", replace
		}
	}

* Nominated politicians*
foreach k in 1982 1985 1988 {
	use "D:/SCB_ConPol/Stata/NomVald/Nominerade_KO_82_85_88_94.dta", clear
	keep if valar == `k'
	capture gen nrinom = .
	capture destring nrinom, replace force
	capture rename Partikod partikod
	gen politiker_`j' = 1
	bysort LopNr: egen parti = mode(partikod), maxmode
	collapse politiker_`j' (min) nrinom parti, by(LopNr) 		
	gen partyabb = ""
	replace partyabb = "c" if parti == 4
	replace partyabb = "l" if parti == 3
	replace partyabb = "kd" if parti == 68
	replace partyabb = "m" if parti == 1
	replace partyabb = "mp" if parti == 55
	replace partyabb = "s" if parti == 2
	replace partyabb = "v" if parti == 5
	replace partyabb = "sd" if parti == 110
	gen year = `k'
	label var politiker_`j' ""
	save "Nom_`k'_KO.dta", replace
	}

foreach j in LT RI {											
	foreach k in 1982 1985 1988 {
		use "D:/SCB_ConPol/Stata/NomVald/Nominerade_`j'_82_85_88.dta", clear
		keep if valar == `k'
		capture gen nrinom = .
		capture destring nrinom, replace force
		capture rename Partikod partikod
		gen politiker_`j' = 1	
		bysort LopNr: egen parti = mode(partikod), maxmode
		collapse politiker_`j' (min) parti nrinom, by(LopNr) 		
		gen partyabb = ""
		replace partyabb = "c" if parti == 4
		replace partyabb = "l" if parti == 3
		replace partyabb = "kd" if parti == 68
		replace partyabb = "m" if parti == 1
		replace partyabb = "mp" if parti == 55
		replace partyabb = "s" if parti == 2
		replace partyabb = "v" if parti == 5
		replace partyabb = "sd" if parti == 110
		gen year = `k'
		label var politiker_`j' ""
		label var parti ""
		save "Nom_`k'_`j'.dta", replace
		}
	}
foreach j in KO LT RI {
	foreach k in 1991 1994 1998 2002 2006 2010 {
		use "D:/SCB_ConPol/Stata/NomVald/Nom_`k'_`j'.dta", clear
		capture gen nrinom = .
		capture destring nrinom, replace force
		capture rename Partikod partikod
		gen politiker_`j' = 1
		bysort LopNr: egen parti = mode(partikod), maxmode
		collapse politiker_`j' (min) parti nrinom, by(LopNr) 
		gen partyabb = ""
		replace partyabb = "c" if parti == 4
		replace partyabb = "l" if parti == 3
		replace partyabb = "kd" if parti == 68
		replace partyabb = "m" if parti == 1
		replace partyabb = "mp" if parti == 55
		replace partyabb = "s" if parti == 2
		replace partyabb = "v" if parti == 5
		replace partyabb = "sd" if parti == 110
		gen year = `k'
		label var politiker_`j' ""
		label var parti ""
		save "Nom_`k'_`j'.dta", replace
		}
	}
	
* LISA 2009*
use "D:/SCB_ConPol/Stata/LISA/LISA_2009.dta", clear
keep LopNr Sun2000niva_old LoneInk SocBidrFam SyssStatJ
dupprogram
YearsEducation
gen Lisayear = 2014 													
save "LISA_2009.dta", replace

* LISA panel covariates parents			
forvalues k=1990/1993 {
	use "D:/SCB_ConPol/Stata/LISA/LISA_`k'.dta", clear
	keep LopNr SocBidrFam SyssStatG Sun2000niva_old LoneInk 
	gen socialbidragfamilj = 0
	replace socialbidragfamilj=1 if SocBidrFam > 0 & SocBidrFam !=.
	gen sysselsatt = .
	replace sysselsatt=1 if SyssStatG == 1
	replace sysselsatt=0 if SyssStatG == 5 | SyssStatG == 6
	egen zink = std(LoneInk)
	dupprogram
	YearsEducation
	gen avgar=`k'
	keep LopNr yearseducation socialbidragfamilj sysselsatt avgar zink
	save "LISAcovparent_`k'.dta", replace
}
forvalues k=1994/2002 {
	use "D:/SCB_ConPol/Stata/LISA/LISA_`k'.dta", clear
	keep LopNr SocBidrFam SyssStat Sun2000niva_old LoneInk
	gen socialbidragfamilj = 0
	replace socialbidragfamilj=1 if SocBidrFam > 0 & SocBidrFam !=.
	gen sysselsatt = .
	replace sysselsatt=1 if SyssStat == 1
	replace sysselsatt=0 if SyssStat == 5 | SyssStat == 6
	egen zink = std(LoneInk)
	dupprogram
	YearsEducation
	gen avgar=`k'
	keep LopNr yearseducation socialbidragfamilj sysselsatt avgar zink
	save "LISAcovparent_`k'.dta", replace
}
forvalues k=2003/2010 {
	use "D:/SCB_ConPol/Stata/LISA/LISA_`k'.dta", clear
	keep LopNr SocBidrFam SyssStatJ Sun2000niva_old LoneInk
	gen socialbidragfamilj = 0
	replace socialbidragfamilj=1 if SocBidrFam > 0 & SocBidrFam !=.
	gen sysselsatt = .
	replace sysselsatt=1 if SyssStatJ == 1
	replace sysselsatt=0 if SyssStatJ == 5 | SyssStatJ == 6
	egen zink = std(LoneInk)
	dupprogram
	YearsEducation
	gen avgar=`k'
	keep LopNr yearseducation socialbidragfamilj sysselsatt avgar zink
	save "LISAcovparent_`k'.dta", replace
}
**Grades from ninth grade **
use "D:/SCB_ConPol/Stata/Utbild/AK9.dta", clear 
keep LopNr MEDELBETYG MERITVARDE SH
foreach v in MEDELBETYG SH MERITVARDE {
      rename `v' `= lower("`v'")'
}
dupprogram
gen betygsystem = .
replace betygsystem = 0 if medelbetyg !=9
replace betygsystem = 1 if medelbetyg == 9

replace medelbetyg = . if medelbetyg == 9		
replace meritvarde = . if medelbetyg !=.
gen GPA_9 = medelbetyg
replace GPA_9 = meritvarde if medelbetyg == .
drop medelbetyg meritvarde
save "AK9.dta", replace

*SAMS areas*
forvalues k = 1982/2010 {
	use "D:/SCB_ConPol/Stata/SAMS/SAMS_`k'.dta", clear
	gen year = `k'
	keep LopNr year SAMS
	dupprogram
	save "SAMS_`k'.dta", replace
}

*Political interest, ULF*
forvalues k=1997(1)2010 {
	use "D:/SCB_ConPol/Stata/ULF/ulf`k'.dta", clear  
	tostring *, replace
	gen ulfyear = `k'
	save "ulf`k'.dta", replace
}


use "ulf1997.dta", clear
forvalues k=1998(1)2010 {
	append using "ulf`k'"
}
keep LopNr MA0200 ulfyear

gen discpol = 0
replace discpol = 1 if MA0200 == "4" 											/*Coding this variable as if if participating often and 0 otherwise*/
replace discpol = . if ulfyear == 2006 											/*Variable missing in ULF 2006*/
drop MA0200

bysort LopNr (ulfyear): gen counter = _n										/*Saving first year in the panel*/
keep if counter == 1

destring LopNr, replace
save "polintULF.dta", replace

****************
clear all
log close
